/* 
 * Copyright (c) 2012, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */
/*
 *  ======== app_config.c ========
 *  Configuration for evm3530 Linux app. In this example, the engine alg
 *  table has no local algs. Remote algs will be added at runtime when the
 *  server is loaded.
 */

#include <xdc/std.h>

/*
 *  ======== Engine Configuration ========
 */
#include <ti/sdo/ce/CERuntime.h>
#include <ti/xdais/ialg.h>
#include <ti/xdais/idma3.h>
#include <ti/xdais/ires.h>

/*
 *  Empty engine table. Engine will be created and populated with algs
 *  at run-time.  This is needed to create the global structure Engine_config.
 *  TODO: Get this out.
 */
CE_BEGIN_ENGINE_TABLE(engineTab)
CE_END_ENGINE_TABLE(engineTab)

/*
 *  Set to TRUE if app will be loading and starting the slave. Set to FALSE
 *  if using slaveloader to load and start the slave.
 */
Bool ti_sdo_ce_ipc_dsplink__Processor_loadSlave = TRUE;

/*
 *  ======== ti.sdo.ce Settings Configuration ========
 *  Set to TRUE for 'checked' builds.
 */
Bool VISA_checked = FALSE;

/*
 * ======== ti.sdo.ce.alg.Algorithm Configuration ========
 */

/*
 *  ======== useHeap ========
 *  Flag indicating whether algorithm memory should be allocated from
 *  a heap or from a pool.
 *
 *  This flag is currently only used when CMEM is used to allocate memory
 *  (e.g. ARM-side 'local' codecs).
 */
Bool ti_sdo_ce_alg_Algorithm_useHeap = FALSE;

/*
 *  ======== useCache ========
 *  This flag indicates whether algorithm memory should be allocated from
 *  cache-enabled buffers.
 *
 *  This flag is currently only used when CMEM is used to allocate memory
 *  (e.g. ARM-side 'local' codecs).
 *
 *  Note that when cache-enabled buffers are used, it is the application's
 *  responsibility to manage this cache.  See the various `Memory_` APIs
 *  for cache services.
 */
Bool ti_sdo_ce_alg_Algorithm_useCache = FALSE;
/*
 *  @(#) ti.sdo.ce.examples.apps; 1, 0, 0,1; 1-17-2012 23:09:42; /db/atree/library/trees/ce/ce-t03/src/ xlibrary

 */

